@@ -1,7 +1,7 @@
 globalVariables(c('%>%', '.', 'AIC', 'S', 'annvalue', 'met', 'bl', 'lwr', 'upr', 'cont_year', 'bt_met', 
                   'bt_lwr', 'bt_upr', 'day', 'doy', 'month', 'pval', 'se', 'trans', 'value', 'xmax', 'xmin', 
                   'xval', 'yr', 'yrcoef', 'appr_yrcoef', 'yrcoef_lwr', 'yrcoef_upr', 'dayCounts', 'data', 
-                  'psig'))
+                  'psig', 'trnd'))
                 
 #' @importFrom stats AIC as.formula coef coefficients lm na.exclude na.omit pt predict qnorm resid sd update
 NULL
\ No newline at end of file
