@@ -4,6 +4,6 @@ test_that("Checking anlz_smooth", {
     dplyr::pull(p.value) %>% 
     round(2)
   
-  expect_equal(result, 0)
+  expect_equal(result, 0.01)
   
 })
